//=======================================================================
// about.h
//-----------------------------------------------------------------------
// This file is part of the package paco
// Copyright (C) 2004-2009 David Rosal
// For more information visit http://paco.sourceforge.net
//=======================================================================

#ifndef GPACO_ABOUT_H
#define GPACO_ABOUT_H

#include <gtkmm/aboutdialog.h>

namespace Gpaco {

class About : public Gtk::AboutDialog
{
	public:

	About();

	private:

	void response(int);
};

} // namespace Gpaco


#endif  // GPACO_ABOUT_H

